@@ -39,6 +39,8 @@
 #define SETTINGS_CURRENTSCHEMEID	"scheme"
 #define SETTINGS_CURRENTCONNECTION	"connection"
 
+#define MIDIJ_FILESCHEMEFILTER		"*.xml"
+
 
 #define WINDOW_BAR_HEIGHT	68
 
@@ -52,11 +54,12 @@
 MidiJ::MidiJ(QWidget *parent)
     : QGraphicsView(parent)
 {
-    setStyleSheet(QString::fromUtf8("border: 0px solid; background-color:black"));
+//    setStyleSheet(QString::fromUtf8("border: 0px"));
 //    setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
-/*    setOptimizationFlags(QGraphicsView::DontClipPainter
-                                   | QGraphicsView::DontSavePainterState
-                                   | QGraphicsView::DontAdjustForAntialiasing);*/
+	setOptimizationFlags(QGraphicsView::DontAdjustForAntialiasing);
+    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
 	m_scene.setBackgroundBrush(QBrush(Qt::black));
 	setScene(&m_scene);
 
@@ -68,7 +71,7 @@ MidiJ::MidiJ(QWidget *parent)
 
 	m_router = new RouterObject();
 	m_midiControler = new MidiObjectGuiEmul();
-	m_midiConnection = new MidiObjectUdp(MidiObjectUdp::OutputOnly);
+	m_midiConnection = new MidiObjectUdp(MidiObjectUdp::BidirClient);
 	m_midiConnection->updateDeviceList();
 }
 
@@ -154,12 +157,12 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 	m_currentSchemeId = settings.value(SETTINGS_CURRENTSCHEMEID).toString();
 	if (m_currentSchemeId.isEmpty())
 	{
-		m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Blue_SSL.xml").absoluteFilePath();
+		m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Blue_Gen.xml").absoluteFilePath();
 	}
-	m_currentMidiConn = settings.value(SETTINGS_CURRENTCONNECTION, "UDP [5004]").toString();
+	m_currentMidiConn = settings.value(SETTINGS_CURRENTCONNECTION, "UDP/IP [5004/5]").toString();
 #else
-	m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Stanton_SSL.xml").absoluteFilePath();
-	m_currentMidiConn = "UDP [5004]";
+	m_currentSchemeId = QFileInfo(schemeHomeDir + "midij_Stanton_Gen.xml").absoluteFilePath();
+	m_currentMidiConn = "UDP/IP [5004/5]";
 #endif
 
 	// create "Menu" items
@@ -173,8 +176,8 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 	// CLOSE button
 	QRect closeButtonRect(desktopSize().width() - 80, 0, 80, 65);
 	QPixmap closePix, closeHiPix;
-	closePix.load(homeDir + "images/close04_62.png");
-	closeHiPix.load(homeDir + "images/close04_hi.png");
+	closePix.load(":/images/close04_62.png");
+	closeHiPix.load(":/images/close04_hi.png");
 	if (closePix.isNull() || closeHiPix.isNull())
 	{
 		qFatal("fail to open CLOSE icons");
@@ -187,8 +190,8 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 	// task switch button
 	QRect taskButtonRect(0, 0, 80, 65);
 	QPixmap taskPix, taskHiPix;
-	taskPix.load(homeDir + "images/task04_62.png");
-	taskHiPix.load(homeDir + "images/task04_hi.png");
+	taskPix.load(":/images/task04_62.png");
+	taskHiPix.load(":/images/task04_hi.png");
 	if (taskPix.isNull() || taskHiPix.isNull())
 	{
 		qFatal("fail to open TASK icons");
@@ -201,8 +204,8 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 	// settings button
 	QRect setupButtonRect(2 + 80, 0, 80, 65);
 	QPixmap toolsPix, toolsHiPix;
-	toolsPix.load(homeDir + "images/tools04_62.png");
-	toolsHiPix.load(homeDir + "images/tools04_hi.png");
+	toolsPix.load(":/images/tools04_62.png");
+	toolsHiPix.load(":/images/tools04_hi.png");
 	if (toolsPix.isNull() || toolsHiPix.isNull())
 	{
 		qFatal("fail to open TOOLS icons");
@@ -232,13 +235,13 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 	connect(&m_menuHideFastTimer, SIGNAL(timeout()), SLOT(menuHideFast()));
 
 	m_menuVisible = true;
-	
-	// TODO icon 48x48???
-	m_defaultSchemeIcon48 = QIcon(homeDir + "images/midij_48.png");
+
+	// icon 48x48 for Schemes without icon
+	m_defaultSchemeIcon48 = QIcon(":/images/midij_48.png");
 
 	// find scheme header files
 	QStringList fileExtList;
-	fileExtList.append("*.xml");
+	fileExtList.append(MIDIJ_FILESCHEMEFILTER);
 
 	DirContext dc1(schemeHomeDir);
 	QDirIterator xmlHeadersIt(QDir::currentPath(), fileExtList, QDir::Files);
@@ -279,21 +282,6 @@ bool MidiJ::init(QString homeDir, QString schemeHomeDir, QString schemeAltDir)
 
 bool MidiJ::loadSchemeGui(QString schemeFile)
 {
-//	// load presets
-//	QFileInfo xmlPath(m_schemeHomeDir + schemeFile);
-//
-//	DirContext dc(xmlPath);
-//	if (!dc.isValid())
-//	{
-//		qCritical() << "fail to change dir:" << xmlPath.absolutePath();
-//		return false;
-//	}
-//
-//	qDebug() << "current dir:" << QDir::currentPath();
-//
-////	m_scene.removeItem(m_menuGroup);
-//
-//	if (!m_guiMapping.loadSchemeGui(xmlPath.fileName(), m_guiItems))
 	if (!m_guiMapping.loadScheme(schemeFile, m_guiItems))
 		return false;
 
@@ -302,7 +290,7 @@ bool MidiJ::loadSchemeGui(QString schemeFile)
 
 	QPixmap background = m_guiMapping.background();
 	QRect menuButtonRect = m_guiMapping.toggleButtonRect(WINDOW_BAR_HEIGHT); //(140, 0, 200, 60);
-	// TODO setMenuToggleButton(m_guiMapping.background(), menuButtonRect);
+	// XXX setMenuToggleButton(m_guiMapping.background(), menuButtonRect);
 
 	_delete(m_menuToggleButton);
 	m_menuToggleButton = new GraphicsClickItem(background.copy(menuButtonRect), QPixmap(), menuButtonRect);
@@ -320,15 +308,23 @@ bool MidiJ::loadSchemeGui(QString schemeFile)
 
 bool MidiJ::loadEngineRouterPreset()
 {
-	// setup connnections
+	// setup connections:
+	// GUI -> MidiController/Engine
 	m_guiMapping.connectMidiOutPort(m_midiControler, SLOT(emulReceive(uchar,uchar,uchar)));
-	m_guiMapping.connectMidiInPort(m_midiControler);
-//	connect(m_midiControler, SIGNAL(emulSendShortMsg(uchar,uchar,uchar)), &m_guiMapping, SLOT(midiShortMsgIn(uchar,uchar,uchar)));
-//	connect(m_midiControler, SIGNAL(emulSendSysexMsg(uchar*,uint)), &m_guiMapping, SLOT(midiSysexMsgIn(uchar*,uint)), Qt::DirectConnection);
+	connect(m_midiControler, SIGNAL(emulSendShortMsg(uchar,uchar,uchar)), &m_guiMapping, SLOT(midiShortMsgIn(uchar,uchar,uchar)));
+	connect(m_midiControler, SIGNAL(emulSendSysexMsg(uchar*,uint)), &m_guiMapping, SLOT(midiSysexMsgIn(uchar*,uint)), Qt::DirectConnection);
 
+
+	// MidiController/Engine -> Router -> Gateway
 	m_router->setMidiObjects(m_midiControler, m_midiConnection);
+	connect(m_midiControler, SIGNAL(midiThru(MidiMessage,char)), m_router, SLOT(midiSourceReceive(MidiMessage,char)));
+	connect(m_midiControler->getMidiScriptEngine(), SIGNAL(initialized()), m_router, SLOT(sourceReload()));
+
+	// Gateway -> GUI mapping (SysEx messages from gateway)
 	connect(m_midiConnection, SIGNAL(midiSysexMsgOut(uchar*,uint)), &m_guiMapping, SLOT(midiSysexMsgIn(uchar*,uint)), Qt::DirectConnection);
-	connect(&m_guiMapping, SIGNAL(midiSysexMsgOut(QByteArray)), m_router, SLOT(midiSysexMsgIn(uchar*,uint)), Qt::DirectConnection);
+
+	// GUI mapping -> Router (SysEx messages reply)
+	connect(&m_guiMapping, SIGNAL(midiSysexMsgOut(uchar*,uint)), m_router, SLOT(midiGatewaySysexMsgOut(uchar*,uint)), Qt::DirectConnection);
 
 
 	progressLoadingScreen(LSPB_GUIMAPPING_MIDICONTRL);
@@ -357,9 +353,17 @@ bool MidiJ::loadEngineRouterPreset()
 
 bool MidiJ::loadSimplePreset()
 {
-	// TODO support midiConnection directly from GUI
-	m_guiMapping.connectMidiOutPort(m_router, SLOT(emulReceive(uchar,uchar,uchar)));
-	m_guiMapping.connectMidiInPort(m_router);
+	// setup connections:
+	m_router->setMidiObjects(NULL, m_midiConnection);
+	// GUI mapping -> MidiConnection
+	m_guiMapping.connectMidiOutPort(m_router, SLOT(midiGatewayShortMsgOut(uchar,uchar,uchar)));
+	// GUI mapping -> MidiConnection (SysEx messages reply)
+	connect(&m_guiMapping, SIGNAL(midiSysexMsgOut(uchar*,uint)), m_router, SLOT(midiGatewaySysexMsgOut(uchar*,uint)), Qt::DirectConnection);
+
+	// MidiConnection -> GUI
+	connect(m_midiConnection, SIGNAL(midiThru(MidiMessage,char)), &m_guiMapping, SLOT(midiShortMsgIn(MidiMessage,char)));
+	connect(m_midiConnection, SIGNAL(midiSysexMsg(uchar*,uint)), &m_guiMapping, SLOT(midiSysexMsgIn(uchar*,uint)), Qt::DirectConnection);
+
 	progressLoadingScreen(LSPB_GUIMAPPING_END);
 	return false;//not yet// true;
 }
@@ -403,16 +407,15 @@ void MidiJ::runScheme()
 	m_guiMapping.init();
 	showLoadingScreen(false);
 
-    QApplication::instance()->processEvents();
+	QApplication::instance()->processEvents();
 
-    // if engine, engine->callInit()
-
-    if (m_midiControler != NULL)
-    {
-    	MidiMapping* midiMapping = m_midiControler->getMidiMapping();
-    	if (midiMapping != NULL)
-    		midiMapping->callInit();
-    }
+	// if engine, engine->callInit()
+	if (m_midiControler != NULL)
+	{
+		MidiMapping* midiMapping = m_midiControler->getMidiMapping();
+		if (midiMapping != NULL)
+			midiMapping->callInit();
+	}
     if (m_router != NULL)
     {
     	RouterMapping* routerMapping = m_router->getRouterMapping();
@@ -420,7 +423,11 @@ void MidiJ::runScheme()
     		routerMapping->callInit();
     }
 
-    QTimer::singleShot(1000, this, SLOT(menuHide()));
+    if (m_midiConnection->getOpenDevice().isEmpty())
+    {
+		QMaemo5InformationBox::information(this, "Fail to open network MIDI connection");
+    }
+	QTimer::singleShot(1000, this, SLOT(menuHide()));
 }
 
 void MidiJ::doClose()
@@ -488,7 +495,9 @@ void MidiJ::doSettings()
 			m_guiItems.clear();
 			m_guiMapping.clear();
 			m_router->clear();
+			m_midiControler->disconnect();
 			m_midiControler->devClose();
+			m_midiControler->getMidiMapping()->clearPreset();
 
 			// load new skin...
 			m_currentSchemeId = newSchemeId;
