@@ -29,11 +29,6 @@ public:
 	MidiObjectGuiEmul();
 	virtual ~MidiObjectGuiEmul();
 
-	void connectMidiThruPort(QObject* router)
-	{
-//TODO corrigir os slots
-		connect(this, SIGNAL(midiThru(MidiMessage,char)), router, SLOT(midiSourceReceive(MidiMessage,char)));
-	};
 public slots:
 	void emulReceive(uchar status, uchar midicontrol, uchar midivalue);
 
