@@ -21,17 +21,25 @@
 
 MidiSysexProperties::MidiSysexProperties(const QString& str)
 {
-	QStringList property = str.split(':');
-	m_name = property.at(0);
+	QStringList propertiesList = str.split(';');
+	foreach(QString property, propertiesList)
+	{
+		QStringList propertyTokens = property.split(':');
+		if (propertyTokens.size() == 2)
+		{
+			m_name = propertyTokens.at(0).trimmed();
 
-	// TODO switch(g_name2Type.value(m_name))
-	//{
-	// case QVariant::Bool:
-	m_value = QVariant(property.at(1) == "true");
-	m_validProps = true;
-	// default:
-	//	m_validProps = true;
-	//}
+			// TODO zzz; propIndex = meta->indexOfProperty(m_name)
+			// switch( meta->property(propIndex).type() )
+			//{
+			// case QVariant::Bool:
+			m_value = QVariant(propertyTokens.at(1).trimmed() == "true");
+			m_validProps = true;
+			// default:
+			//	m_validProps = false;
+			//}
+		}
+	}
 }
 
 MidiSysexProperties::~MidiSysexProperties()
