@@ -603,14 +603,15 @@ void MidiMapping::applyPreset() {
  * Creates a blank bindings preset.
  */
 void MidiMapping::clearPreset() {
-    Q_ASSERT(!m_mappingLock.tryLock());
+//--MidiJ    Q_ASSERT(!m_mappingLock.tryLock());
     // Create a new blank DomNode
     //SE_DEL//    QString blank = "<MixxxMIDIPreset schemaVersion=\"" + QString(XML_SCHEMA_VERSION) + "\" mixxxVersion=\"" + QString(VERSION) + "+\">\n"
     QString blank = "<MixxxMIDIPreset schemaVersion=\"1\" mixxxVersion=\"1+\">\n"
     "</MixxxMIDIPreset>\n";
     QDomDocument doc("Bindings");
     doc.setContent(blank);
-    m_Bindings = doc.documentElement();
+//--MidiJ    m_Bindings = doc.documentElement();
+    loadPreset(doc.documentElement(), false); // ++MidiJ
 }
 
 /* buildDomElement()
